Command Line Interface
======================
bioregistry automatically installs the command :code:`bioregistry`. See
:code:`bioregistry --help` for usage details.

.. click:: bioregistry.cli:main
   :prog: bioregistry
   :show-nested:
